aboutsummaryrefslogtreecommitdiffstats
path: root/pkg/report/linux.go
diff options
context:
space:
mode:
authorAndrey Konovalov <andreyknvl@google.com>2017-11-28 15:39:18 +0100
committerDmitry Vyukov <dvyukov@google.com>2017-11-28 15:54:13 +0100
commit7bd85f2aea5965969505c075cc4451ac69c650b0 (patch)
tree3f1b3c40e476fdc4c2ec94c592bec49a14d06b1a /pkg/report/linux.go
parentac93d7e1d83ffac19983e9d754a47e7808f1230e (diff)
pkg/report: fix corrupted stack trace detection
Look for stack frames in the next 10 lines after 'Call Trace' instead of 3.
Diffstat (limited to 'pkg/report/linux.go')
-rw-r--r--pkg/report/linux.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/pkg/report/linux.go b/pkg/report/linux.go
index 2e29fb1ca..ae66c1b27 100644
--- a/pkg/report/linux.go
+++ b/pkg/report/linux.go
@@ -365,8 +365,8 @@ func (ctx *linux) isCorrupted(title string, report []byte, format oopsFormat) bo
}
frames = frames[1:]
corrupted := true
- // Check that at least one of the next 3 lines contains a frame.
- for i := 0; i < 3; i++ {
+ // Check that at least one of the next 10 lines contains a frame.
+ for i := 0; i < 10; i++ {
if bytes.Contains(frames[i], []byte("(stack is not available)")) || linuxSymbolizeRe.Match(frames[i]) {
corrupted = false
break